@@ -23,18 +23,16 @@ import os
 import shutil
 import time
 
+from ironic_lib import disk_utils
 from oslo_concurrency import processutils
 from oslo_log import log as logging
 from oslo_utils import fileutils
 import pycdlib
 
-from ironic.common import checksum_utils
 from ironic.common import exception
 from ironic.common.glance_service import service_utils as glance_utils
 from ironic.common.i18n import _
-from ironic.common import image_format_inspector
 from ironic.common import image_service as service
-from ironic.common import qemu_img
 from ironic.common import utils
 from ironic.conf import CONF
 
@@ -177,8 +175,7 @@ def _label(files_info):
 
 
 def create_isolinux_image_for_bios(
-        output_file, kernel, ramdisk, kernel_params=None, inject_files=None,
-        publisher_id=None):
+        output_file, kernel, ramdisk, kernel_params=None, inject_files=None):
     """Creates an isolinux image on the specified file.
 
     Copies the provided kernel, ramdisk to a directory, generates the isolinux
@@ -194,8 +191,6 @@ def create_isolinux_image_for_bios(
         as the kernel cmdline.
     :param inject_files: Mapping of local source file paths to their location
         on the final ISO image.
-    :param publisher_id: A value to set as the publisher identifier string
-        in the ISO image to be generated.
     :raises: ImageCreationFailed, if image creation failed while copying files
         or while running command to generate iso.
     """
@@ -242,12 +237,9 @@ def create_isolinux_image_for_bios(
         isolinux_cfg = os.path.join(tmpdir, ISOLINUX_CFG)
         utils.write_to_file(isolinux_cfg, cfg)
 
-        # Set a publisher ID value to a string.
-        pub_id = str(publisher_id)
-
         try:
             utils.execute('mkisofs', '-r', '-V', _label(files_info),
-                          '-J', '-l', '-publisher', pub_id, '-no-emul-boot',
+                          '-J', '-l', '-no-emul-boot',
                           '-boot-load-size', '4', '-boot-info-table',
                           '-b', ISOLINUX_BIN, '-o', output_file, tmpdir)
         except processutils.ProcessExecutionError as e:
@@ -257,7 +249,7 @@ def create_isolinux_image_for_bios(
 
 def create_esp_image_for_uefi(
         output_file, kernel, ramdisk, deploy_iso=None, esp_image=None,
-        kernel_params=None, inject_files=None, publisher_id=None):
+        kernel_params=None, inject_files=None):
     """Creates an ESP image on the specified file.
 
     Copies the provided kernel, ramdisk and EFI system partition image (ESP) to
@@ -279,8 +271,6 @@ def create_esp_image_for_uefi(
         as the kernel cmdline.
     :param inject_files: Mapping of local source file paths to their location
         on the final ISO image.
-    :param publisher_id: A value to set as the publisher identifier string
-        in the ISO image to be generated.
     :raises: ImageCreationFailed, if image creation failed while copying files
         or while running command to generate iso.
     """
@@ -347,18 +337,10 @@ def create_esp_image_for_uefi(
         utils.write_to_file(grub_cfg, grub_conf)
 
         # Create the boot_iso.
-        if publisher_id:
-            args = ('mkisofs', '-r', '-V', _label(files_info),
-                    '-l', '-publisher', publisher_id, '-e', e_img_rel_path,
-                    '-no-emul-boot', '-o', output_file,
-                    tmpdir)
-        else:
-            args = ('mkisofs', '-r', '-V', _label(files_info),
-                    '-l', '-e', e_img_rel_path,
-                    '-no-emul-boot', '-o', output_file,
-                    tmpdir)
         try:
-            utils.execute(*args)
+            utils.execute('mkisofs', '-r', '-V', _label(files_info),
+                          '-l', '-e', e_img_rel_path, '-no-emul-boot',
+                          '-o', output_file, tmpdir)
 
         except processutils.ProcessExecutionError as e:
             LOG.exception("Creating ISO image failed.")
@@ -387,25 +369,31 @@ def fetch_into(context, image_href, image_file):
               {'image_href': image_href, 'time': time.time() - start})
 
 
-def fetch(context, image_href, path, force_raw=False,
-          checksum=None, checksum_algo=None):
+def fetch(context, image_href, path, force_raw=False):
     with fileutils.remove_path_on_error(path):
         fetch_into(context, image_href, path)
-        if (not CONF.conductor.disable_file_checksum
-                and checksum):
-            checksum_utils.validate_checksum(path, checksum, checksum_algo)
+
     if force_raw:
         image_to_raw(image_href, path, "%s.part" % path)
 
 
 def get_source_format(image_href, path):
-    try:
-        img_format = image_format_inspector.detect_file_format(path)
-    except image_format_inspector.ImageFormatError:
+    data = disk_utils.qemu_img_info(path)
+
+    fmt = data.file_format
+    if fmt is None:
         raise exception.ImageUnacceptable(
-            reason=_("parsing of the image failed."),
+            reason=_("'qemu-img info' parsing failed."),
             image_id=image_href)
-    return str(img_format)
+
+    backing_file = data.backing_file
+    if backing_file is not None:
+        raise exception.ImageUnacceptable(
+            image_id=image_href,
+            reason=_("fmt=%(fmt)s backed by: %(backing_file)s") %
+            {'fmt': fmt, 'backing_file': backing_file})
+
+    return fmt
 
 
 def force_raw_will_convert(image_href, path_tmp):
@@ -418,46 +406,24 @@ def force_raw_will_convert(image_href, path_tmp):
 
 def image_to_raw(image_href, path, path_tmp):
     with fileutils.remove_path_on_error(path_tmp):
-        if not CONF.conductor.disable_deep_image_inspection:
-            fmt = safety_check_image(path_tmp)
+        fmt = get_source_format(image_href, path_tmp)
 
-            if fmt not in CONF.conductor.permitted_image_formats:
-                LOG.error("Security: The requested image %(image_href)s "
-                          "is of format image %(format)s and is not in "
-                          "the [conductor]permitted_image_formats list.",
-                          {'image_href': image_href,
-                           'format': fmt})
-                raise exception.InvalidImage()
-        else:
-            fmt = get_source_format(image_href, path)
-            LOG.warning("Security: Image safety checking has been disabled. "
-                        "This is unsafe operation. Attempting to continue "
-                        "the detected format %(img_fmt)s for %(path)s.",
-                        {'img_fmt': fmt,
-                         'path': path})
-
-        if fmt != "raw" and fmt != "iso":
-            # When the target format is NOT raw, we need to convert it.
-            # however, we don't need nor want to do that when we have
-            # an ISO image. If we have an ISO because it was requested,
-            # we have correctly fingerprinted it. Prior to proper
-            # image detection, we thought we had a raw image, and we
-            # would end up asking for a raw image to be made a raw image.
+        if fmt != "raw":
             staged = "%s.converted" % path
 
             utils.is_memory_insufficient(raise_if_fail=True)
             LOG.debug("%(image)s was %(format)s, converting to raw",
                       {'image': image_href, 'format': fmt})
             with fileutils.remove_path_on_error(staged):
-                qemu_img.convert_image(path_tmp, staged, 'raw',
-                                       source_format=fmt)
+                disk_utils.convert_image(path_tmp, staged, 'raw')
                 os.unlink(path_tmp)
-                new_fmt = get_source_format(image_href, staged)
-                if new_fmt != "raw":
+
+                data = disk_utils.qemu_img_info(staged)
+                if data.file_format != "raw":
                     raise exception.ImageConvertFailed(
                         image_id=image_href,
                         reason=_("Converted to raw, but format is "
-                                 "now %s") % new_fmt)
+                                 "now %s") % data.file_format)
 
                 os.rename(staged, path)
         else:
@@ -488,11 +454,11 @@ def converted_size(path, estimate=False):
         the original image scaled by the configuration value
         `raw_image_growth_factor`.
     """
-    data = image_format_inspector.detect_file_format(path)
+    data = disk_utils.qemu_img_info(path)
     if not estimate:
         return data.virtual_size
     growth_factor = CONF.raw_image_growth_factor
-    return int(min(data.actual_size * growth_factor, data.virtual_size))
+    return int(min(data.disk_size * growth_factor, data.virtual_size))
 
 
 def get_image_properties(context, image_href, properties="all"):
@@ -532,7 +498,7 @@ def get_temp_url_for_glance_image(context, image_uuid):
 def create_boot_iso(context, output_filename, kernel_href,
                     ramdisk_href, deploy_iso_href=None, esp_image_href=None,
                     root_uuid=None, kernel_params=None, boot_mode=None,
-                    inject_files=None, publisher_id=None):
+                    inject_files=None):
     """Creates a bootable ISO image for a node.
 
     Given the hrefs for kernel, ramdisk, root partition's UUID and
@@ -558,8 +524,6 @@ def create_boot_iso(context, output_filename, kernel_href,
     :boot_mode: the boot mode in which the deploy is to happen.
     :param inject_files: Mapping of local source file paths to their location
         on the final ISO image.
-    :param publisher_id: A value to set as the publisher identifier string
-        in the ISO image to be generated.
     :raises: ImageCreationFailed, if creating boot ISO failed.
     """
     with utils.tempdir() as tmpdir:
@@ -596,14 +560,12 @@ def create_boot_iso(context, output_filename, kernel_href,
             create_esp_image_for_uefi(
                 output_filename, kernel_path, ramdisk_path,
                 deploy_iso=deploy_iso_path, esp_image=esp_image_path,
-                kernel_params=params, inject_files=inject_files,
-                publisher_id=publisher_id)
+                kernel_params=params, inject_files=inject_files)
 
         else:
             create_isolinux_image_for_bios(
                 output_filename, kernel_path, ramdisk_path,
-                kernel_params=params, inject_files=inject_files,
-                publisher_id=publisher_id)
+                kernel_params=params, inject_files=inject_files)
 
 
 IMAGE_TYPE_PARTITION = 'partition'
@@ -753,7 +715,7 @@ def _get_deploy_iso_files(deploy_iso, mountdir):
 
     :param deploy_iso: path to the deploy iso where its
                        contents are fetched to.
-    :raises: ImageCreationFailed if mount fails.
+    :raises: ImageCreationFailed if extraction fails.
     :returns: a tuple consisting of - 1. a dictionary containing
                                          the values as required
                                          by create_isolinux_image,
@@ -805,92 +767,3 @@ def _get_deploy_iso_files(deploy_iso, mountdir):
     # present in deploy iso. This path varies for different OS vendors.
     # e_img_rel_path: is required by mkisofs to generate boot iso.
     return uefi_path_info, e_img_rel_path, grub_rel_path
-
-
-def __node_or_image_cache(node):
-    """A helper for logging to determine if image cache or node uuid."""
-    if not node:
-        return 'image cache'
-    else:
-        return node.uuid
-
-
-def safety_check_image(image_path, node=None):
-    """Performs a safety check on the supplied image.
-
-    This method triggers the image format inspector's to both identify the
-    type of the supplied file and safety check logic to identify if there
-    are any known unsafe features being leveraged, and return the detected
-    file format in the form of a string for the caller.
-
-    :param image_path: A fully qualified path to an image which needs to
-                       be evaluated for safety.
-    :param node: A Node object, optional. When supplied logging indicates the
-                 node which triggered this issue, but the node is not
-                 available in all invocation cases.
-    :returns: a string representing the the image type which is used.
-    :raises: InvalidImage when the supplied image is detected as unsafe,
-             or the image format inspector has failed to parse the supplied
-             image's contents.
-    """
-    id_string = __node_or_image_cache(node)
-    try:
-        img_class = image_format_inspector.detect_file_format(image_path)
-        if not img_class.safety_check():
-            LOG.error("Security: The requested image for "
-                      "deployment of node %(node)s fails safety sanity "
-                      "checking.",
-                      {'node': id_string})
-            raise exception.InvalidImage()
-        image_format_name = str(img_class)
-    except image_format_inspector.ImageFormatError:
-        LOG.error("Security: The requested user image for the "
-                  "deployment node %(node)s failed to be able "
-                  "to be parsed by the image format checker.",
-                  {'node': id_string})
-        raise exception.InvalidImage()
-    return image_format_name
-
-
-def check_if_image_format_is_permitted(img_format,
-                                       expected_format=None,
-                                       node=None):
-    """Checks image format consistency.
-
-    :params img_format: The determined image format by name.
-    :params expected_format: Optional, the expected format based upon
-        supplied configuration values.
-    :params node: A node object or None implying image cache.
-    :raises: InvalidImage if the requested image format is not permitted
-             by configuration, or the expected_format does not match the
-             determined format.
-    """
-
-    id_string = __node_or_image_cache(node)
-    if img_format not in CONF.conductor.permitted_image_formats:
-        LOG.error("Security: The requested deploy image for node %(node)s "
-                  "is of format image %(format)s and is not in the "
-                  "[conductor]permitted_image_formats list.",
-                  {'node': id_string,
-                   'format': img_format})
-        raise exception.InvalidImage()
-    if expected_format is not None and img_format != expected_format:
-        if expected_format in ['ari', 'aki']:
-            # In this case, we have an ari or aki, meaning we're pulling
-            # down a kernel/ramdisk, and this is rooted in a misunderstanding.
-            # They should be raw. The detector should be detecting this *as*
-            # raw anyway, so the data just mismatches from a common
-            # misunderstanding, and that is okay in this case as they are not
-            # passed to qemu-img.
-            # TODO(TheJulia): Add a log entry to warn here at some point in
-            # the future as we begin to shift the perception around this.
-            # See: https://bugs.launchpad.net/ironic/+bug/2074090
-            return
-        LOG.error("Security: The requested deploy image for node %(node)s "
-                  "has a format (%(format)s) which does not match the "
-                  "expected image format (%(expected)s) based upon "
-                  "supplied or retrieved information.",
-                  {'node': id_string,
-                   'format': img_format,
-                   'expected': expected_format})
-        raise exception.InvalidImage()
