@@ -125,9 +125,12 @@ class BaseConductorManager(object):
         self._keepalive_evt = threading.Event()
         """Event for the keepalive thread."""
 
-        # TODO(dtantsur): make the threshold configurable?
-        rejection_func = rejection.reject_when_reached(
-            CONF.conductor.workers_pool_size)
+        # NOTE(dtantsur): do not allow queuing work. Given our model, it's
+        # better to reject an incoming request with HTTP 503 or reschedule
+        # a periodic task that end up with hidden backlog that is hard
+        # to track and debug. Using 1 instead of 0 because of how things are
+        # ordered in futurist (it checks for rejection first).
+        rejection_func = rejection.reject_when_reached(1)
         self._executor = futurist.GreenThreadPoolExecutor(
             max_workers=CONF.conductor.workers_pool_size,
             check_and_reject=rejection_func)
@@ -318,13 +321,20 @@ class BaseConductorManager(object):
         # This is only used in tests currently. Delete it?
         self._periodic_task_callables = periodic_task_callables
 
+    def keepalive_halt(self):
+        if not hasattr(self, '_keepalive_evt'):
+            return
+        self._keepalive_evt.set()
+
     def del_host(self, deregister=True, clear_node_reservations=True):
         # Conductor deregistration fails if called on non-initialized
         # conductor (e.g. when rpc server is unreachable).
         if not hasattr(self, 'conductor'):
             return
+
+        # the keepalive heartbeat greenthread will continue to run, but will
+        # now be setting online=False
         self._shutdown = True
-        self._keepalive_evt.set()
 
         if clear_node_reservations:
             # clear all locks held by this conductor before deregistering
@@ -466,7 +476,7 @@ class BaseConductorManager(object):
             return
         while not self._keepalive_evt.is_set():
             try:
-                self.conductor.touch()
+                self.conductor.touch(online=not self._shutdown)
             except db_exception.DBConnectionError:
                 LOG.warning('Conductor could not connect to database '
                             'while heartbeating.')
