@@ -29,7 +29,6 @@ from oslo_utils import excutils
 from oslo_utils import strutils
 from oslo_utils import timeutils
 
-from ironic.common import async_steps
 from ironic.common import boot_devices
 from ironic.common import exception
 from ironic.common import faults
@@ -491,7 +490,9 @@ def cleaning_error_handler(task, logmsg, errmsg=None, traceback=False,
         node.clean_step = {}
         # Clear any leftover metadata about cleaning
         node.del_driver_internal_info('clean_step_index')
-        async_steps.remove_node_flags(node)
+        node.del_driver_internal_info('cleaning_reboot')
+        node.del_driver_internal_info('cleaning_polling')
+        node.del_driver_internal_info('skip_current_clean_step')
         # We don't need to keep the old agent URL, or token
         # as it should change upon the next cleaning attempt.
         wipe_token_and_url(task)
@@ -552,8 +553,10 @@ def wipe_deploy_internal_info(task):
     node.del_driver_internal_info('user_deploy_steps')
     node.del_driver_internal_info('agent_cached_deploy_steps')
     node.del_driver_internal_info('deploy_step_index')
+    node.del_driver_internal_info('deployment_reboot')
+    node.del_driver_internal_info('deployment_polling')
+    node.del_driver_internal_info('skip_current_deploy_step')
     node.del_driver_internal_info('steps_validated')
-    async_steps.remove_node_flags(node)
 
 
 def wipe_cleaning_internal_info(task):
@@ -564,9 +567,11 @@ def wipe_cleaning_internal_info(task):
     node.set_driver_internal_info('clean_steps', None)
     node.del_driver_internal_info('agent_cached_clean_steps')
     node.del_driver_internal_info('clean_step_index')
+    node.del_driver_internal_info('cleaning_reboot')
+    node.del_driver_internal_info('cleaning_polling')
     node.del_driver_internal_info('cleaning_disable_ramdisk')
+    node.del_driver_internal_info('skip_current_clean_step')
     node.del_driver_internal_info('steps_validated')
-    async_steps.remove_node_flags(node)
 
 
 def wipe_service_internal_info(task):
@@ -576,9 +581,11 @@ def wipe_service_internal_info(task):
     node.set_driver_internal_info('service_steps', None)
     node.del_driver_internal_info('agent_cached_service_steps')
     node.del_driver_internal_info('service_step_index')
+    node.del_driver_internal_info('service_reboot')
+    node.del_driver_internal_info('service_polling')
     node.del_driver_internal_info('service_disable_ramdisk')
+    node.del_driver_internal_info('skip_current_service_step')
     node.del_driver_internal_info('steps_validated')
-    async_steps.remove_node_flags(node)
 
 
 def deploying_error_handler(task, logmsg, errmsg=None, traceback=False,
@@ -1110,10 +1117,7 @@ def fast_track_able(task):
             # TODO(TheJulia): Should we check the provisioning/deployment
             # networks match config wise? Do we care? #decisionsdecisions
             and task.driver.storage.should_write_image(task)
-            and task.node.last_error is None
-            # NOTE(dtantsur): Fast track makes zero sense for servicing and
-            # may prevent normal clean-up from happening.
-            and task.node.provision_state not in states.SERVICING_STATES)
+            and task.node.last_error is None)
 
 
 def value_within_timeout(value, timeout):
@@ -1261,8 +1265,14 @@ def update_next_step_index(task, step_type):
     :param step_type: The type of steps to process: 'clean' or 'deploy'.
     :returns: Index of the next step.
     """
-    skip_current_step = async_steps.prepare_node_for_next_step(
-        task.node, step_type)
+    skip_current_step = task.node.del_driver_internal_info(
+        'skip_current_%s_step' % step_type, True)
+    if step_type == 'clean':
+        task.node.del_driver_internal_info('cleaning_polling')
+    else:
+        task.node.del_driver_internal_info('deployment_polling')
+    task.node.save()
+
     return _get_node_next_steps(task, step_type,
                                 skip_current_step=skip_current_step)
 
@@ -1797,7 +1807,9 @@ def servicing_error_handler(task, logmsg, errmsg=None, traceback=False,
         node.service_step = {}
         # Clear any leftover metadata about cleaning
         node.del_driver_internal_info('service_step_index')
-        async_steps.remove_node_flags(node)
+        node.del_driver_internal_info('servicing_reboot')
+        node.del_driver_internal_info('servicing_polling')
+        node.del_driver_internal_info('skip_current_service_step')
         # We don't need to keep the old agent URL, or token
         # as it should change upon the next cleaning attempt.
         wipe_token_and_url(task)
@@ -1835,6 +1847,31 @@ def node_cache_firmware_components(task):
                       task.node.uuid)
 
 
+def run_node_action(task, call, error_msg, success_msg=None, **kwargs):
+    """Run a node action and report any errors via last_error.
+
+    :param task: A TaskManager instance containing the node to act on.
+    :param call: A callable object to invoke.
+    :param error_msg: A template for a failure message. Can use %(node)s,
+        %(exc)s and any variables from kwargs.
+    :param success_msg: A template for a success message. Can use %(node)s
+        and any variables from kwargs.
+    :param kwargs: Arguments to pass to the call.
+    """
+    error = None
+    try:
+        call(task, **kwargs)
+    except Exception as exc:
+        error = error_msg % dict(kwargs, node=task.node.uuid, exc=exc)
+        node_history_record(task.node, event=error, error=True)
+        LOG.error(
+            error, exc_info=not isinstance(exc, exception.IronicException))
+
+    task.node.save()
+    if not error and success_msg:
+        LOG.info(success_msg, dict(kwargs, node=task.node.uuid))
+
+
 def node_update_cache(task):
     """Updates various cached information.
 
