@@ -33,6 +33,7 @@ from ironic.common import boot_devices
 from ironic.common import exception
 from ironic.common.i18n import _
 from ironic.common import molds
+from ironic.common import states
 from ironic.conductor import periodics
 from ironic.conductor import task_manager
 from ironic.conductor import utils as manager_utils
@@ -365,7 +366,7 @@ class DracRedfishManagement(redfish_management.RedfishManagement):
     @base.clean_step(priority=0, argsinfo=EXPORT_CONFIGURATION_ARGSINFO,
                      requires_ramdisk=False)
     def export_configuration(self, task, export_configuration_location):
-        """Export the configuration of the server.
+        """(Deprecated) Export the configuration of the server.
 
         Exports the configuration of the server against which the step is run
         and stores it in specific format in indicated location.
@@ -415,7 +416,7 @@ class DracRedfishManagement(redfish_management.RedfishManagement):
     @base.clean_step(priority=0, argsinfo=IMPORT_CONFIGURATION_ARGSINFO,
                      requires_ramdisk=False)
     def import_configuration(self, task, import_configuration_location):
-        """Import and apply the configuration to the server.
+        """(Deprecated) Import and apply the configuration to the server.
 
         Gets pre-created configuration from storage by given location and
         imports that into given server. Uses Dell's Server Configuration
@@ -623,9 +624,22 @@ class DracRedfishManagement(redfish_management.RedfishManagement):
                      on.
         :raises: RedfishError on an error.
         """
-        drac_utils.execute_oem_manager_method(
-            task, 'clear job queue',
-            lambda m: m.job_service.delete_jobs(job_ids=['JID_CLEARALL']))
+        try:
+            drac_utils.execute_oem_manager_method(
+                task, 'clear job queue',
+                lambda m: m.job_service.delete_jobs(job_ids=['JID_CLEARALL']))
+        except exception.RedfishError as exc:
+            if "Oem/Dell/DellJobService is missing" in str(exc):
+                LOG.warning('iDRAC on node %(node)s does not support '
+                            'clearing Lifecycle Controller job queue '
+                            'using the idrac-redfish driver. '
+                            'If using iDRAC9, consider upgrading firmware. '
+                            'If using iDRAC8, consider switching to '
+                            'idrac-wsman for management interface if '
+                            'possible.',
+                            {'node': task.node.uuid})
+            if task.node.provision_state != states.VERIFYING:
+                raise
 
     @METRICS.timer('DracRedfishManagement.reset_idrac')
     @base.verify_step(priority=0)
@@ -637,11 +651,23 @@ class DracRedfishManagement(redfish_management.RedfishManagement):
                      on.
         :raises: RedfishError on an error.
         """
-        drac_utils.execute_oem_manager_method(
-            task, 'reset iDRAC', lambda m: m.reset_idrac())
-        redfish_utils.wait_until_get_system_ready(task.node)
-        LOG.info('Reset iDRAC for node %(node)s done',
-                 {'node': task.node.uuid})
+        try:
+            drac_utils.execute_oem_manager_method(
+                task, 'reset iDRAC', lambda m: m.reset_idrac())
+            redfish_utils.wait_until_get_system_ready(task.node)
+            LOG.info('Reset iDRAC for node %(node)s done',
+                     {'node': task.node.uuid})
+        except exception.RedfishError as exc:
+            if "Oem/Dell/DelliDRACCardService is missing" in str(exc):
+                LOG.warning('iDRAC on node %(node)s does not support '
+                            'iDRAC reset using the idrac-redfish driver. '
+                            'If using iDRAC9, consider upgrading firmware. '
+                            'If using iDRAC8, consider switching to '
+                            'idrac-wsman for management interface if '
+                            'possible.',
+                            {'node': task.node.uuid})
+            if task.node.provision_state != states.VERIFYING:
+                raise
 
     @METRICS.timer('DracRedfishManagement.known_good_state')
     @base.verify_step(priority=0)
@@ -664,6 +690,10 @@ class DracRedfishManagement(redfish_management.RedfishManagement):
 
 class DracWSManManagement(base.ManagementInterface):
 
+    # NOTE(TheJulia): Deprecating November 2023 in favor of Redfish
+    # and due to a lack of active driver maintenance.
+    supported = False
+
     def get_properties(self):
         """Return the properties of the interface."""
         return drac_common.COMMON_PROPERTIES
