@@ -44,9 +44,8 @@ def _attach_boot_iso_if_needed(task):
 
     This method checks the instance info of the baremetal node for a
     boot iso. If the instance info has a value of key 'boot_iso',
-    it indicates that 'boot_option' is 'netboot'. Therefore it attaches
-    the boot ISO on the baremetal node and then sets the node to boot from
-    virtual media cdrom.
+    it indicates ramdisk deploy. Therefore it attaches the boot ISO on the
+    baremetal node and then sets the node to boot from virtual media cdrom.
 
     :param task: a TaskManager instance containing the node to act on.
     """
@@ -175,9 +174,12 @@ def _wait_for_state_change(node, target_state, requested_state,
     else:
         timeout = int(max_retry * interval)
         LOG.error("iLO failed to change state to %(tstate)s "
-                  "within %(timeout)s sec for node %(node)s",
+                  "within %(timeout)s sec for node %(node)s. Reported "
+                  "state from iLO is %(state)s, expected state from iLO "
+                  "is %(expected)s.",
                   {'tstate': target_state, 'node': node.uuid,
-                   'timeout': int(max_retry * interval)})
+                   'timeout': int(max_retry * interval), 'state': state[0],
+                   'expected': state_to_check})
         raise exception.PowerStateFailure(pstate=target_state)
 
 
