@@ -30,9 +30,8 @@ sushy = importutils.try_import('sushy')
 
 LOG = log.getLogger(__name__)
 METRICS = metrics_utils.get_metrics_logger(__name__)
-SUBSCRIPTION_FIELDS_REMOVE = {
-    '@odata.context', '@odate.etag', '@odata.id', '@odata.type',
-    'HttpHeaders', 'Oem', 'Name', 'Description'
+SUBSCRIPTION_COMMON_FIELDS = {
+    'Id', 'Context', 'Protocol', 'Destination', 'EventTypes'
 }
 
 
@@ -97,6 +96,8 @@ class RedfishVendorPassthru(base.VendorInterface):
     def eject_vmedia(self, task, **kwargs):
         """Eject a virtual media device.
 
+        Deprecated in favour of the generic API.
+
         :param task: A TaskManager object.
         :param kwargs: The arguments sent with vendor passthru. The optional
             kwargs are::
@@ -111,8 +112,11 @@ class RedfishVendorPassthru(base.VendorInterface):
         """Verify that the args input are valid."""
         destination = kwargs.get('Destination')
         event_types = kwargs.get('EventTypes')
-        context = kwargs.get('Context')
-        protocol = kwargs.get('Protocol')
+        # NOTE(iurygregory): Use defaults values from Redfish in case they
+        # are not present in the args.
+        context = kwargs.get('Context', "")
+        protocol = kwargs.get('Protocol', "Redfish")
+        http_headers = kwargs.get('HttpHeaders')
 
         if event_types is not None:
             event_service = redfish_utils.get_event_service(task.node)
@@ -134,10 +138,22 @@ class RedfishVendorPassthru(base.VendorInterface):
             raise exception.InvalidParameterValue(
                 _("Protocol %s is not a string") % protocol)
 
+        # NOTE(iurygregory): if http_headers are None there is no problem,
+        # the validation will fail if the value is not None and not a list.
+        if http_headers is not None and not isinstance(http_headers, list):
+            raise exception.InvalidParameterValue(
+                _("HttpHeaders %s is not a list of headers") % http_headers)
+
         try:
             parsed = rfc3986.uri_reference(destination)
-            if not parsed.is_valid(require_scheme=True,
-                                   require_authority=True):
+            validator = rfc3986.validators.Validator().require_presence_of(
+                'scheme', 'host',
+            ).check_validity_of(
+                'scheme', 'userinfo', 'host', 'path', 'query', 'fragment',
+            )
+            try:
+                validator.validate(parsed)
+            except rfc3986.exceptions.RFC3986Exception:
                 # NOTE(iurygregory): raise error because the parsed
                 # destination does not contain scheme or authority.
                 raise TypeError
@@ -147,14 +163,14 @@ class RedfishVendorPassthru(base.VendorInterface):
 
     def _filter_subscription_fields(self, subscription_json):
         filter_subscription = {k: v for k, v in subscription_json.items()
-                               if k not in SUBSCRIPTION_FIELDS_REMOVE}
+                               if k in SUBSCRIPTION_COMMON_FIELDS}
         return filter_subscription
 
     @METRICS.timer('RedfishVendorPassthru.create_subscription')
     @base.passthru(['POST'], async_call=False,
                    description=_("Creates a subscription on a node. "
                                  "Required argument: a dictionary of "
-                                 "{'destination': 'destination_url'}"))
+                                 "{'Destination': 'destination_url'}"))
     def create_subscription(self, task, **kwargs):
         """Creates a subscription.
 
@@ -170,6 +186,10 @@ class RedfishVendorPassthru(base.VendorInterface):
             'EventTypes': kwargs.get('EventTypes', ["Alert"])
         }
 
+        http_headers = kwargs.get('HttpHeaders', [])
+        if http_headers:
+            payload['HttpHeaders'] = http_headers
+
         try:
             event_service = redfish_utils.get_event_service(task.node)
             subscription = event_service.subscriptions.create(payload)
@@ -196,7 +216,7 @@ class RedfishVendorPassthru(base.VendorInterface):
                                  "Required argument: a dictionary of "
                                  "{'id': 'subscription_bmc_id'}"))
     def delete_subscription(self, task, **kwargs):
-        """Creates a subscription.
+        """Delete a subscription.
 
         :param task: A TaskManager object.
         :param kwargs: The arguments sent with vendor passthru.
@@ -225,7 +245,7 @@ class RedfishVendorPassthru(base.VendorInterface):
                                                   'node': task.node.uuid,
                                                   'error': e})
             LOG.error(error_msg)
-            raise exception.RedfishError(error=error_msg)
+            raise exception.RedfishError(error=error_msg, code=404)
 
     @METRICS.timer('RedfishVendorPassthru.get_subscriptions')
     @base.passthru(['GET'], async_call=False,
