@@ -77,14 +77,12 @@ class TestACLBase(base.BaseApiTest):
     def _fake_process_request(self, request, auth_token_request):
         pass
 
-    def _test_request(self, path, params=None, headers=None, method='get',  # noqa: C901, E501
+    def _test_request(self, path, params=None, headers=None, method='get',
                       body=None, assert_status=None,
                       assert_dict_contains=None,
                       assert_list_length=None,
                       deprecated=None,
-                      self_manage_nodes=True,
-                      enable_service_project=False,
-                      service_project='service'):
+                      self_manage_nodes=True):
         path = path.format(**self.format_data)
         self.mock_auth.side_effect = self._fake_process_request
 
@@ -94,13 +92,6 @@ class TestACLBase(base.BaseApiTest):
                 'project_admin_can_manage_own_nodes',
                 False,
                 'api')
-        if enable_service_project:
-            cfg.CONF.set_override('rbac_service_role_elevated_access', True)
-        if service_project != 'service':
-            # Enable us to sort of gracefully test a name variation
-            # with existing ddt test modeling.
-            cfg.CONF.set_override('rbac_service_project_name',
-                                  service_project)
 
         # always request the latest api version
         version = api_versions.max_version_string()
