@@ -18,7 +18,6 @@ from unittest import mock
 
 from oslo_utils import importutils
 from oslo_utils import uuidutils
-import swiftclient.exceptions
 
 from ironic.common import context as ironic_context
 from ironic.common import exception
@@ -125,10 +124,8 @@ class SwiftCleanUp(db_base.DbTestCase):
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=False) as task:
             swift_obj_mock.delete_object.side_effect = [
-                swiftclient.exceptions.ClientException("not found",
-                                                       http_status=404),
-                swiftclient.exceptions.ClientException("not found",
-                                                       http_status=404)]
+                exception.SwiftObjectNotFoundError("not found"),
+                exception.SwiftObjectNotFoundError("not found")]
             utils.clean_up_swift_entries(task)
 
     @mock.patch.object(swift, 'SwiftAPI', autospec=True)
@@ -140,10 +137,8 @@ class SwiftCleanUp(db_base.DbTestCase):
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=False) as task:
             swift_obj_mock.delete_object.side_effect = [
-                swiftclient.exceptions.ClientException("failed",
-                                                       http_status=417),
-                swiftclient.exceptions.ClientException("not found",
-                                                       http_status=404)]
+                exception.SwiftOperationError("failed"),
+                exception.SwiftObjectNotFoundError("not found")]
             self.assertRaises(exception.SwiftObjectStillExists,
                               utils.clean_up_swift_entries, task)
 
@@ -156,10 +151,8 @@ class SwiftCleanUp(db_base.DbTestCase):
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=False) as task:
             swift_obj_mock.delete_object.side_effect = [
-                swiftclient.exceptions.ClientException("failed",
-                                                       http_status=417),
-                swiftclient.exceptions.ClientException("failed",
-                                                       http_status=417)]
+                exception.SwiftOperationError("failed"),
+                exception.SwiftOperationError("failed")]
             self.assertRaises((exception.SwiftObjectStillExists,
                                exception.SwiftObjectStillExists),
                               utils.clean_up_swift_entries, task)
@@ -388,6 +381,36 @@ class LookupNodeTestCase(db_base.DbTestCase):
         self.assertRaises(exception.NotFound, utils.lookup_node,
                           self.context, self.macs, [self.bmc2], None)
 
+    def test_duplicate_bmc(self):
+        # This can happen with Redfish. There is no way to resolve the conflict
+        # other than by using MACs.
+        obj_utils.create_test_node(
+            self.context,
+            uuid=uuidutils.generate_uuid(),
+            driver_internal_info={utils.LOOKUP_CACHE_FIELD: [self.bmc]},
+            provision_state=states.INSPECTWAIT)
+        self.assertRaises(exception.NotFound, utils.lookup_node,
+                          self.context, [], [self.bmc], None)
+
+    def test_duplicate_bmc_and_unknown_mac(self):
+        obj_utils.create_test_node(
+            self.context,
+            uuid=uuidutils.generate_uuid(),
+            driver_internal_info={utils.LOOKUP_CACHE_FIELD: [self.bmc]},
+            provision_state=states.INSPECTWAIT)
+        self.assertRaises(exception.NotFound, utils.lookup_node,
+                          self.context, [self.unknown_mac], [self.bmc], None)
+
+    def test_duplicate_bmc_resolved_by_macs(self):
+        obj_utils.create_test_node(
+            self.context,
+            uuid=uuidutils.generate_uuid(),
+            driver_internal_info={utils.LOOKUP_CACHE_FIELD: [self.bmc]},
+            provision_state=states.INSPECTWAIT)
+        result = utils.lookup_node(
+            self.context, [self.macs[0]], [self.bmc], None)
+        self.assertEqual(self.node.uuid, result.uuid)
+
     def test_by_uuid(self):
         result = utils.lookup_node(self.context, [], [], self.node.uuid)
         self.assertEqual(self.node.uuid, result.uuid)
